//--------------------------------------------------------------------------------
// Copyright (c) 2001-2008 by PDFTron Systems Inc. All Rights Reserved.
//--------------------------------------------------------------------------------
using System;
using System.Runtime.InteropServices;
using System.Collections;

namespace test
{

	class Class1
	{
        public delegate Int32 PDF2SVGCallback(int mode, string msg, IntPtr user_data);

        // The following three lines import the PDF2SVG functions from PDF2SVG.dll (via PInvoke).
		[DllImport("pdf2svg.dll")]
		public static extern int PDF2SVGInit(string user_name, string company, string license_key, string resource_path);

		[DllImport("pdf2svg.dll")]
		public static extern int PDF2SVGRun(string command_str, PDF2SVGCallback funct, IntPtr user_data);

		// You can modify the following lines with your registration information.
		static string username = "John Doe";
		static string company = "My Company";
		static string lic_key = "my license key";

		static int PDF2SVG_ERROR = 1;    // Show the error message
		static int PDF2SVG_MSG = 2;      // Report the message
		static int PDF2SVG_GETPASS = 3;  // Get the password
		static int PDF2SVG_OUT_FILENAME = 4; // Get the saved filenames

		// A custom callback that can be used to report errors and other messages.
		public static Int32 MyCallback(int mode, string msg, IntPtr user_data)
		{
			if (mode == PDF2SVG_ERROR) {
				Console.WriteLine("Error: {0}", msg);
			}
			else if (mode == PDF2SVG_MSG) {
				Console.Write("{0}", msg);
			}
			else if (mode == PDF2SVG_GETPASS) {
				//gl_pass = Console.ReadLine();
				// return gl_pass.c_str();
			}
			else if(mode == PDF2SVG_OUT_FILENAME)
			{
				//check whether the IntPtr is valid
				if(user_data.ToInt32() != 0)
				{
					//cast it to a GCHandle to
					//obtain the ArrayList
					GCHandle gch = (GCHandle)user_data;
					ArrayList list = (ArrayList)gch.Target;
					//add the newly created file's path
					list.Add(msg);
				}
			}

			return 0;
		}

		static void Main(string[] args)
		{
			PDF2SVGInit(username, company, lic_key, null);
			PDF2SVGCallback mycallback = new PDF2SVGCallback(MyCallback);

			 // Variable used to switch between different code samples.
			int example = 1;

			if (example == 1) 
			{
				// The simplest PDF2SVG program: Pass an explicit command-line string.
				//
				// This example converts 'tiger.pdf' to 'tiger.svg'
				// To convert all PDF documents in 'TestFiles' folder simply delete 'tiger.pdf'
				// from the command string.
				// 
				// For a detailed explanation of all commands, please refer to PDF2SVG SDK User 
				// Manual. Also, PDF2SVG Command-Line application is a great tool to experiment 
				// with the available options.
				PDF2SVGRun("-o TestOutput/test1 TestFiles/tiger.pdf", mycallback, new IntPtr(0));
			}
			else if (example == 2) 
			{
				// An example of how to use PDF2SVG SDK to implement a command-line application
				// for converting PDF documents to SVG.
				String s = "";
				foreach (string arg in args)
				{
					s += arg + " ";
				}

				PDF2SVGRun(s, mycallback, new IntPtr(0));
			}
			else if (example == 3) 
			{
				// An example of how to dynamically build a command string based on 
				// user settings...
				//
				// Please note that this sample does not cover all possible options offered by 
				// PDF2SVG. For a detailed explanation of all commands, please refer to PDF2SVG 
				// SDK User Manual.
				string output_folder = "TestOutput/test1";
				string open_password = "secret";
				bool compress_using_svgz = true;
				bool embedimages = true;
				bool generate_xml_masterdoc = false;
				bool generate_thumbnails = false; 
				int thumbsize = 150;
				string filename_prefix = "";
				int filename_digits = 4;

				// Given the above settings build a command string.
				String s = "";
				
				if (output_folder != "") s += "-o " + output_folder + " ";
				if (open_password != "") s += "-p " + open_password + " ";
				if (compress_using_svgz) s += "--svgz ";
				if (embedimages) s += "--embedimages ";
				if (generate_xml_masterdoc == false) s += "--noxmldoc ";
				if (generate_thumbnails) 
				{
					s += "--thumbsize " + thumbsize + " ";
				}
				else 
				{
					s += "--nothumbs ";
				}

				if (filename_prefix != "") s += "--prefix " + filename_prefix + " ";
				if (filename_digits>0)  s += "--digits " + filename_digits + " ";

				// specify input PDF files and folders...
				s += "TestFiles/tiger.pdf ";
				s += "TestFiles/tai962.pdf "; 
				// s += "c:/my_pdf_folder "; etc ...


				//an arraylist to store the saved file path(s)
				ArrayList saved_files=new ArrayList();

				//create a GCHandle to allow MyCallback to access
				//the object saved_files
				GCHandle gch = GCHandle.Alloc(saved_files);
				
				// Execute the command string.
				PDF2SVGRun(s, mycallback, (IntPtr)gch);
				gch.Free();

				//print the saved file(s)
				Console.WriteLine("The Saved Files Are:");
				for(int i=0; i<saved_files.Count; i++)
				{
					Console.WriteLine(saved_files[i]);
				}

			}

			Console.WriteLine("Done.");
		}
	}
}
